Help class

Inheritance

Constructors

Help()

Properties

abbr → String
A single-character string that can be used as a shorthand for this option.
no setteroverride
defaultsTo → bool
The value this option will have if the user doesn't explicitly pass it in
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
help → String
A description of this option.
no setteroverride
name → String
The name of the option that the user passes as an argument.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → bool?
The value this option
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited